salesforce-requests-oauthlib
==========================

An extension to requests-oauthlib to specifically support calls to Salesforce APIs.


Tests
-----

To run tests, install py.test and pytest-cov in your virtualenv and

$ py.test --cov=src/salesforce_requests_oauthlib/ --cov-report html:coverage

View test coverage results at ``./coverage``.


Credits
-------

- `modern-package-template`_
- `requests-oauthlib`_
- `requests`_
- `oauthlib`_
- `py.test`_
- `pytest-cov`_

.. _`modern-package-template`: http://pypi.python.org/pypi/modern-package-template
.. _`requests-oauthlib`: https://pypi.python.org/pypi/requests-oauthlib
.. _`requests`: https://pypi.python.org/pypi/requests
.. _`oauthlib`: https://pypi.python.org/pypi/oauthlib
.. _`py.test`: http://doc.pytest.org/en/latest/index.html
.. _`pytest-cov`: https://pypi.python.org/pypi/pytest-cov
